---
title: '[릴리즈노트] 2024-06-17  업데이트'
category: 업데이트
tags:
  - API / SDK
  - 업데이트
searchTags:
  - 결제서비스 V2
  - 'KCP결제모듈 '
  - v2
  - 포트원 v2
  - 업데이트
datetime: 2024-06-16T15:00:00.000Z
---

<Callout title="2024년 6월 17일 API / SDK 업데이트 소식을 안내드립니다." />



## 주요 업데이트 사항

<Tag text="결제 서비스 V2" />

✔️ 포트원 V2 결제모듈에서 NHN KCP 결제를 지원합니다.

이제 포트원 V2를 통해 NHN KCP 일반결제 및 정기결제가 가능합니다. \
이번 업데이트를 통해 다양한 결제수단을 제공하며, 일부 간편결제에 대해 허브형과 다이렉트 호출을 지원합니다.

NHN KCP에서 지원하는 결제수단은 아래와 같습니다.

- 실시간 계좌이체
- 가상계좌
- 휴대폰 소액결제
- 상품권 결제(컬쳐랜드/도서문화상품권)
- 간편결제 (허브형/다이렉트)

<Indent level="1">

- 카카오페이
- 네이버페이
- 페이코
- SSG페이
- L페이
- 삼성페이
- 애플페이
- 토스페이

</Indent>

이 외에도 SDK/API 빌링키 발급, 에스크로, API 가상계좌 발급, 면세 금액 지정, 상점분담무이자 등의 기능을 지원합니다.

NHN KCP 연동에 대해 자세히 알고 싶다면 [→ NHN KCP 연동가이드](https://developers.portone.io/opi/ko/integration/pg/v2/kcp-v2?v=v2)에서 확인하실 수 있습니다.

##### [\[API / SDK 릴리즈노트\] 2024-06-17 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-06-17)
